@@ -1,25 +1,68 @@
 import copy
 import math
 import time
-from typing import Tuple
+from enum import Enum
+from typing import Optional, Tuple
+
+from solders.pubkey import Pubkey
 
 from driftpy.account_subscription_config import AccountSubscriptionConfig
-from driftpy.accounts.oracle import *
+from driftpy.accounts import (
+    DataAndSlot,
+    OraclePriceData,
+    PerpMarketAccount,
+    SpotMarketAccount,
+    UserAccount,
+)
+from driftpy.constants import BASE_PRECISION, PRICE_PRECISION
+from driftpy.constants.numeric_constants import (
+    AMM_RESERVE_PRECISION,
+    FIVE_MINUTE,
+    FUEL_START_TS,
+    GOV_SPOT_MARKET_INDEX,
+    MARGIN_PRECISION,
+    OPEN_ORDER_MARGIN_REQUIREMENT,
+    QUOTE_PRECISION,
+    QUOTE_SPOT_MARKET_INDEX,
+    SPOT_MARKET_WEIGHT_PRECISION,
+)
 from driftpy.math.amm import calculate_market_open_bid_ask
-from driftpy.math.conversion import convert_to_number
-from driftpy.math.fuel import calculate_insurance_fuel_bonus
-from driftpy.math.fuel import calculate_perp_fuel_bonus
-from driftpy.math.fuel import calculate_spot_fuel_bonus
-from driftpy.math.margin import *
+from driftpy.math.fuel import (
+    calculate_insurance_fuel_bonus,
+    calculate_perp_fuel_bonus,
+    calculate_spot_fuel_bonus,
+)
+from driftpy.math.margin import (
+    MarginCategory,
+    calculate_asset_weight,
+    calculate_liability_weight,
+    calculate_market_margin_ratio,
+    calculate_unrealized_asset_weight,
+)
 from driftpy.math.oracles import calculate_live_oracle_twap
-from driftpy.math.perp_position import *
+from driftpy.math.perp_position import (
+    calculate_base_asset_value_with_oracle,
+    calculate_perp_liability_value,
+    calculate_position_funding_pnl,
+    calculate_position_pnl,
+    calculate_worst_case_base_asset_amount,
+    calculate_worst_case_perp_liability_value,
+    is_available,
+)
 from driftpy.math.spot_balance import get_strict_token_value
-from driftpy.math.spot_market import *
-from driftpy.math.spot_position import calculate_weighted_token_value
-from driftpy.math.spot_position import get_worst_case_token_amounts
-from driftpy.math.spot_position import is_spot_position_available
+from driftpy.math.spot_market import get_signed_token_amount, get_token_amount
+from driftpy.math.spot_position import (
+    get_worst_case_token_amounts,
+    is_spot_position_available,
+)
 from driftpy.oracles.strict_oracle_price import StrictOraclePrice
-from driftpy.types import OraclePriceData
+from driftpy.types import (
+    Order,
+    PerpPosition,
+    SpotPosition,
+    UserStatus,
+    is_variant,
+)
 
 
 class DriftUser:
@@ -29,9 +72,7 @@ class DriftUser:
         self,
         drift_client,
         user_public_key: Pubkey,
-        account_subscription: Optional[
-            AccountSubscriptionConfig
-        ] = AccountSubscriptionConfig.default(),
+        account_subscription: AccountSubscriptionConfig = AccountSubscriptionConfig.default(),
     ):
         """Initialize the user object
 
@@ -54,28 +95,32 @@ class DriftUser:
         )
 
     async def subscribe(self):
+        if self.account_subscriber is None:
+            raise ValueError("No account subscriber found")
         await self.account_subscriber.subscribe()
 
     def unsubscribe(self):
+        if self.account_subscriber is None:
+            raise ValueError("No account subscriber found")
         self.account_subscriber.unsubscribe()
 
     def get_oracle_data_for_spot_market(
         self, market_index: int
-    ) -> Optional[OraclePriceData]:
+    ) -> OraclePriceData | None:
         return self.drift_client.get_oracle_price_data_for_spot_market(market_index)
 
     def get_oracle_data_for_perp_market(
         self, market_index: int
-    ) -> Optional[OraclePriceData]:
+    ) -> OraclePriceData | None:
         return self.drift_client.get_oracle_price_data_for_perp_market(market_index)
 
-    def get_perp_market_account(self, market_index: int) -> PerpMarketAccount:
+    def get_perp_market_account(self, market_index: int) -> Optional[PerpMarketAccount]:
         return self.drift_client.get_perp_market_account(market_index)
 
-    def get_spot_market_account(self, market_index: int) -> SpotMarketAccount:
+    def get_spot_market_account(self, market_index: int) -> Optional[SpotMarketAccount]:
         return self.drift_client.get_spot_market_account(market_index)
 
-    def get_user_account_and_slot(self) -> DataAndSlot[UserAccount]:
+    def get_user_account_and_slot(self) -> Optional[DataAndSlot[UserAccount]]:
         return self.account_subscriber.get_user_account_and_slot()
 
     def get_user_account(self) -> UserAccount:
@@ -125,9 +170,8 @@ class DriftUser:
 
     def get_spot_position(self, market_index: int) -> Optional[SpotPosition]:
         for position in self.get_user_account().spot_positions:
-            if (
-                position.market_index == market_index
-                and not is_spot_position_available(position)
+            if position.market_index == market_index and not is_spot_position_available(
+                position
             ):
                 return position
 
@@ -153,6 +197,9 @@ class DriftUser:
             signed,
         )
 
+    def is_high_leverage_mode(self) -> bool:
+        return is_variant(self.get_user_account().margin_mode, "HighLeverage")
+
     def is_being_liquidated(self) -> bool:
         user_account = self.get_user_account()
         return (
@@ -357,9 +404,8 @@ class DriftUser:
 
         found = False
         for position in user.spot_positions:
-            if (
-                position.market_index == market_index
-                and not is_spot_position_available(position)
+            if position.market_index == market_index and not is_spot_position_available(
+                position
             ):
                 found = True
                 break
@@ -402,6 +448,10 @@ class DriftUser:
                 min(100, max(0, (1 - maintenance_margin_req / total_collateral) * 100))
             )
 
+    def get_settled_perp_pnl(self) -> int:
+        user = self.get_user_account()
+        return user.settled_perp_pnl
+
     def get_unrealized_pnl(
         self,
         with_funding: bool = False,
@@ -472,7 +522,7 @@ class DriftUser:
 
     def get_unrealized_funding_pnl(
         self,
-        market_index: int = None,
+        market_index: Optional[int] = None,
     ):
         user = self.get_user_account()
 
@@ -484,6 +534,8 @@ class DriftUser:
             perp_market = self.drift_client.get_perp_market_account(
                 position.market_index
             )
+            if not perp_market:
+                raise Exception("Perp market account not found")
 
             unrealized_pnl += calculate_position_funding_pnl(perp_market, position)
 
@@ -1479,6 +1531,10 @@ class DriftUser:
         strict: bool = False,
     ) -> int:
         market = self.drift_client.get_perp_market_account(perp_position.market_index)
+        if not market:
+            raise ValueError(
+                f"No perp market account found for market {perp_position.market_index}"
+            )
 
         if perp_position.lp_shares > 0:
             # is an lp, clone so we don't mutate the position
@@ -1486,9 +1542,15 @@ class DriftUser:
                 market.market_index, copy.deepcopy(perp_position), bool(margin_category)
             )
 
-        valuation_price = self.get_oracle_data_for_perp_market(
+        valuation_price_data = self.drift_client.get_oracle_price_data_for_perp_market(
             market.market_index
-        ).price
+        )
+        if not valuation_price_data:
+            raise ValueError(
+                f"No oracle price data found for market {market.market_index}"
+            )
+
+        valuation_price = valuation_price_data.price
         if is_variant(market.status, "Settlement"):
             valuation_price = market.expiry_price
 
