@@ -1,9 +1,11 @@
+from dataclasses import dataclass
+from typing import Optional
+
 from anchorpy import Program
 from solana.rpc.async_api import AsyncClient
 from solana.rpc.commitment import Commitment
-from dataclasses import dataclass
-from typing import Optional
-from driftpy.types import MarketType
+
+from driftpy.types import GrpcConfig, MarketType
 
 
 @dataclass
@@ -18,3 +20,11 @@ class MarketMapConfig:
     market_type: MarketType  # perp market map or spot market map
     subscription_config: WebsocketConfig
     connection: AsyncClient
+
+
+@dataclass
+class GrpcMarketMapConfig:
+    program: Program
+    market_type: MarketType  # perp market map or spot market map
+    grpc_config: GrpcConfig
+    connection: AsyncClient
