@@ -1,14 +1,14 @@
-from dataclasses import dataclass
-from dataclasses import field
 import inspect
-from typing import Optional
-from urllib.parse import urlparse
-from urllib.parse import urlunparse
 import zlib
+from dataclasses import dataclass, field
+from typing import Optional, TypedDict
+from urllib.parse import urlparse, urlunparse
 
 from borsh_construct.enum import _rust_enum
+from solana.rpc.commitment import Commitment
 from solders.pubkey import Pubkey
 from sumtypes import constructor
+from typing_extensions import NotRequired
 
 
 def is_variant(enum, type: str) -> bool:
@@ -240,7 +240,6 @@ class MarginCalculationMode:
 class OracleSource:
     Pyth = constructor()
     Switchboard = constructor()
-    SwitchboardOnDemand = constructor()
     QuoteAsset = constructor()
     Pyth1K = constructor()
     Pyth1M = constructor()
@@ -250,6 +249,10 @@ class OracleSource:
     Pyth1KPull = constructor()
     Pyth1MPull = constructor()
     PythStableCoinPull = constructor()
+    SwitchboardOnDemand = constructor()
+    PythLazer = constructor()
+    PythLazer1K = constructor()
+    PythLazer1M = constructor()
 
 
 @_rust_enum
@@ -340,6 +343,14 @@ class UserStatus:
     BEING_LIQUIDATED = 1
     BANKRUPT = 2
     REDUCE_ONLY = 4
+    ADVANCED_UP = 8
+    PROTECTED_MAKER = 16
+
+
+@_rust_enum
+class MarginMode:
+    Default = constructor()
+    HighLeverage = constructor()
 
 
 @_rust_enum
@@ -350,6 +361,22 @@ class OrderStatus:
     Canceled = constructor()
 
 
+class OracleSourceNum:
+    PYTH = 0
+    SWITCHBOARD = 6
+    QUOTE_ASSET = 7
+    PYTH_1K = 1
+    PYTH_1M = 2
+    PYTH_STABLE_COIN = 8
+    PRELAUNCH = 10
+    PYTH_PULL = 3
+    PYTH_1K_PULL = 4
+    PYTH_1M_PULL = 5
+    PYTH_STABLE_COIN_PULL = 9
+    SWITCHBOARD_ON_DEMAND = 11
+    PYTH_LAZER = 12
+
+
 @_rust_enum
 class OrderType:
     Market = constructor()
@@ -395,7 +422,7 @@ class OrderParams:
     base_asset_amount: int
     market_index: int
     direction: PositionDirection
-    market_type: MarketType = None
+    market_type: MarketType
     user_order_id: int = 0
     price: int = 0
     reduce_only: bool = False
@@ -870,7 +897,7 @@ class UserAccount:
     has_open_order: bool
     open_auctions: int
     has_open_auction: bool
-    last_fuel_bonus_update_ts: int
+    margin_mode: MarginMode
     padding: list[int] = field(default_factory=lambda: [0] * 21)
 
 
@@ -1389,3 +1416,54 @@ class PriceFeedMessage:
 class PriceUpdateV2:
     price_message: PriceFeedMessage
     posted_slot: int
+
+
+@dataclass
+class GrpcConfig:
+    endpoint: str
+    token: str
+    commitment: Commitment = Commitment("confirmed")
+
+
+class OptionalOrderParams(TypedDict, total=False):
+    """All fields are optional except market_type, market_index, direction"""
+
+    order_type: NotRequired[OrderType]
+    base_asset_amount: NotRequired[int]
+    price: NotRequired[int]
+    market_index: int  # required
+    direction: PositionDirection  # required
+    market_type: MarketType  # required
+    user_order_id: NotRequired[int]
+    reduce_only: NotRequired[bool]
+    post_only: NotRequired[PostOnlyParams]
+    immediate_or_cancel: NotRequired[bool]
+    max_ts: NotRequired[Optional[int]]
+    trigger_price: NotRequired[Optional[int]]
+    trigger_condition: NotRequired[OrderTriggerCondition]
+    oracle_price_offset: NotRequired[Optional[int]]
+    auction_duration: NotRequired[Optional[int]]
+    auction_start_price: NotRequired[Optional[int]]
+    auction_end_price: NotRequired[Optional[int]]
+
+
+@dataclass
+class SignedSwiftOrderParams:
+    order_params: bytes
+    signature: bytes
+
+
+@dataclass
+class SwiftTriggerOrderParams:
+    trigger_price: int
+    base_asset_amount: int
+
+
+@dataclass
+class SwiftOrderParamsMessage:
+    swift_order_params: OptionalOrderParams
+    sub_account_id: int
+    slot: int
+    uuid: bytes
+    take_profit_order_params: SwiftTriggerOrderParams | None
+    stop_loss_order_params: SwiftTriggerOrderParams | None
